@@ -90,7 +90,7 @@ class ClientModel(ABC):
         metric_units = guessMetricByType({}, self.dict)
         self.__setitem__('units', metric_units)
 
-    def calculate_total_without_base_values(self):
+    def calculate_total_without_base_values(self) -> str:
         ''' calculate the total of all metrics without base values '''
         total = 0
         for key, value in self.dict.items():
@@ -114,6 +114,7 @@ class ClientModel(ABC):
                 except ValueError:
                     pass
         self.__setitem__('total', total)
+        return total
 
     def set_unit(self, key, value):
         ''' set the unit for the metric '''
