@@ -4,12 +4,26 @@ import json
 import argparse # use argparse to parse the arguments
 from subprocess import call
 from time import strftime
-from site24x7_plugin_helper.connector.database_client import DatabaseClient as Client
-
+from dotenv import load_dotenv
+from site24x7_plugin_helper.connector.database_client import DatabaseClient
+parser = argparse.ArgumentParser(description='This is a helper script for Site24x7 plugins.')
+parser.add_argument('--plugin',
+    help='Unique plugin name that will be shown in site24x7 plugin list',
+    required=True,
+    type=str)
+parser.add_argument('--query',
+    help='MSSQL query to be executed',
+    required=True,
+    type=str)
+parser.add_argument('--version',
+    help="Which step of the plugin is this? (1, 2, 3, etc.)",
+    required=False,
+    type=int)
+parser.add_argument('--env', help='Path to .env file', default='.env')
+# load the environment variables from file location
+load_dotenv(dotenv_path=parser.parse_args().env)
+# DEBUG
 PASS_DATABASE_CONNECTION = True
-class DatabaseClient(Client):
-    def database_type(self):
-        return "MSSQL"
 
 def special_strftime():
     ''' expected output: Aug 22nd, 2022 '''
@@ -23,30 +37,26 @@ def special_strftime():
     return x + dic.get(x[-2:], 'th,') + year
 
 if __name__ == "__main__":
-    # server informations are given as arguments
-    server = sys.argv[1]
-    database = sys.argv[2]
-    username = sys.argv[3]
-    password = sys.argv[4]
-    driver_location = sys.argv[5] # /opt/microsoft/msodbcsql17/lib64/libmsodbcsql-17.5.so.1.1
-    query = sys.argv[6]
-    this_plugin_name = sys.argv[7]
+    this_plugin_name = parser.parse_args().plugin
+    query = parser.parse_args().query
+    server = os.environ.get("SERVER")
+    database = os.environ.get("DATABASE")
+    username = os.environ.get("DATABASE_USERNAME")
+    password = os.environ.get("DATABASE_PASSWORD")
+    # /opt/microsoft/msodbcsql17/lib64/libmsodbcsql-17.5.so.1.1
+    driver_location = os.environ.get("DATABASE_DRIVER_PATH")
     cache = {
-        #"server":server,
         "database":database,
-        #"username":username,
-        #"password":password,
-        #"driver_location":driver_location,
         "query":query,
         "this_plugin_name":this_plugin_name,
     }
     if not PASS_DATABASE_CONNECTION:
-        DatabaseClient = DatabaseClient(server, database, username, password, driver_location)
-        cursor = DatabaseClient.cursor
+        client = DatabaseClient(server, database, username, password, driver_location)
+        cursor = client.cursor
         print("connnected")
         # existing query that returns all rows from the table for caching
         # 'EXEC [Ultramerchant].dbo.pr_membership_credit_billing_stats_24x7_monitor_sel'
-        rows = DatabaseClient.fetchall(query)
+        rows = client.fetchall(query)
         for i in enumerate(rows):
             key = rows[i][1]
             value = rows[i][2]
@@ -61,14 +71,11 @@ if __name__ == "__main__":
     )
     print(json.dumps(cache, indent=4, sort_keys=True))
 
-    SITE24x7_LOCATION = "/opt/site24x7/monagent/plugins"
-    folder_destination = os.path.join(SITE24x7_LOCATION, this_plugin_name)
+    SITE24X7_LOCATION = "/opt/site24x7/monagent/plugins"
+    folder_destination = os.path.join(SITE24X7_LOCATION, this_plugin_name)
     file_destination = os.path.join(folder_destination, this_plugin_name + ".py")
     print("folder_destination: " + folder_destination)
     print("file_destination: " + file_destination)
-    # BELOW PROCESS WILL BE DONE BY JENKINS
-    # BECAUSE IT IS BREAKING PATH LOCATION WITH //
-    # /opt/site24x7/monagent/plugins
     # create a folder if not exists
     if not os.path.exists(folder_destination):
         call(f"mkdir {folder_destination}", shell=True)
@@ -83,7 +90,7 @@ if __name__ == "__main__":
 '''
 from site24x7_plugin_helper.connector.cache_client import CacheClient
 
-CacheClient = CacheClient(
+CLIENT = CacheClient(
     "{cache_file_name}",
     author="Renas Mirkan Kilic",
     plugin_version="1",
@@ -93,14 +100,14 @@ CacheClient = CacheClient(
 def metric_collector():
     data = {{}}
     try:
-        CacheClient.set_metric_types()
-        data.update(CacheClient.dict)
+        CLIENT.set_metric_types()
+        data.update(CLIENT.dict)
     except Exception as err:
         data["error"] = str(err)
-    CacheClient.__setitem__("thisPluginName", "{this_plugin_name}")
+    CLIENT.__setitem__("thisPluginName", "{this_plugin_name}")
     return data
 
 if __name__ == "__main__":
     result = metric_collector()
-    print(CacheClient.dumps(result))
-""" )
+    print(CLIENT.dumps(result))
+""")
